"""
consumer_grant automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
from .consumer_app import ConsumerApp
class ConsumerGrant(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    app: Optional[ConsumerApp] = Field(default=None, alias="app")
    create_date: Optional[datetime.datetime] = Field(default=None, alias="createDate")
    pass
