"""
consumer_token_update automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
class ConsumerTokenUpdate(BaseModel):
    name: Optional[str] = Field(default=None, alias="name")
    expire: Optional[datetime.date] = Field(default=None, alias="expire")
    pass
