"""
common_form_element_text_area automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .common_form_element import CommonFormElement
class CommonFormElementTextArea(CommonFormElement):
    mode: Optional[str] = Field(default=None, alias="mode")
    pass
