"""
backend_marketplace_app automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class BackendMarketplaceApp(BaseModel):
    version: Optional[str] = Field(default=None, alias="version")
    description: Optional[str] = Field(default=None, alias="description")
    screenshot: Optional[str] = Field(default=None, alias="screenshot")
    website: Optional[str] = Field(default=None, alias="website")
    download_url: Optional[str] = Field(default=None, alias="downloadUrl")
    sha_hash: Optional[str] = Field(default=None, alias="sha1Hash")
    start_url: Optional[str] = Field(default=None, alias="startUrl")
    pass
