"""
backend_marketplace_local_app automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_marketplace_app import BackendMarketplaceApp
class BackendMarketplaceLocalApp(BackendMarketplaceApp):
    remote: Optional[BackendMarketplaceApp] = Field(default=None, alias="remote")
    pass
